@@ -9,6 +9,8 @@ __all__ = [
     "ns_path",
     "clone",
     "source_manifest",
+    "remote_push_manifest",
+    "remote_pull_manifest",
     "yaml_manifests",
     "get_yaml_manifest",
     "change_build_dir"
