@@ -4,7 +4,7 @@ from ..manifest.man import ssm
 from sys import stderr
 from git import Repo
 
-__all__ = ["clone", "source_manifest", "git_news", "remote_push_manifest"]
+__all__ = ["clone", "source_manifest", "git_news", "remote_push_manifest", "remote_pull_manifest"]
 
 
 def clone(url, as_name=None, wd=ns_path, update_man=True):
@@ -71,14 +71,23 @@ def git_news(repo, abbreviate_at=2):
     return news
 
 
-def remote_push_manifest(commit_msg=None):
+def remote_push_manifest(commit_msg=None, specific_domains=None):
     """
     Run `git add --all` on each repo in the manifest (`qu.ssm`),
     i.e. apex and all subdomains, then `git commit -m "..."`
     where `...` is replaced by `commit_msg` or auto-generated
     if no commit is available.
     """
-    for domain in ssm.repos_df.domain:
+    if specific_domains is None:
+        domains = ssm.repos_df.domain
+    else:
+        if type(specific_domains) is list:
+            domains = specific_domains
+        elif type(specific_domains) is str:
+            domains = [specific_domains]
+        else:
+            raise TypeError(f"Unexpected type for {specific_domains=}")
+    for domain in domains:
         repo_dir = ns_path / domain
         if not repo_dir.exists():
             print(f"Skipping '{repo_dir=!s}' (doesn't exist)", file=stderr)
@@ -101,3 +110,35 @@ def remote_push_manifest(commit_msg=None):
             print(f"⇢ Pushing ⠶ {origin.name}", file=stderr)
     ssm.check_manifest()
     return
+
+def remote_pull_manifest(specific_domains=None):
+    """
+    Run `git pull` on each repo in the manifest (`qu.ssm`),
+    i.e. apex and all subdomains.
+    
+    No merge method is specified (unclear whether this will be necessary).
+
+    See here if there are problems:
+    https://stackoverflow.com/questions/36891470/how-to-pull-with-gitpython
+    """
+    if specific_domains is None:
+        domains = ssm.repos_df.domain
+    else:
+        if type(specific_domains) is list:
+            domains = specific_domains
+        elif type(specific_domains) is str:
+            domains = [specific_domains]
+        else:
+            raise TypeError(f"Unexpected type for {specific_domains=}")
+    for domain in domains:
+        print(f"Examining {domain}...", file=stderr)
+        repo_dir = ns_path / domain
+        if not repo_dir.exists():
+            print(f"Skipping '{repo_dir=!s}' (doesn't exist)", file=stderr)
+            continue  # simply do not touch for now
+        repo = Repo(repo_dir)
+        origin = repo.remote(name="origin")
+        origin.pull() # not checked if returned Pull object stores useful info
+        print(f"⇢ Pulling ⠶ {origin.name}", file=stderr)
+    ssm.check_manifest()
+    return
